@@ -5,13 +5,16 @@ from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
     from typing_extensions import TypeGuard
+    from . import _types as _t
 
-from . import _types as _t
 from .utils import trace
 
 
 def scm_find_files(
-    path: _t.PathT, scm_files: set[str], scm_dirs: set[str]
+    path: _t.PathT,
+    scm_files: set[str],
+    scm_dirs: set[str],
+    force_all_files: bool = False,
 ) -> list[str]:
     """ setuptools compatible file finder that follows symlinks
 
@@ -20,6 +23,7 @@ def scm_find_files(
       (including symlinks to directories)
     - scm_dirs: set of scm controlled directories
       (including directories containing no scm controlled files)
+    - force_all_files: ignore ``scm_files`` and ``scm_dirs`` and list everything.
 
     scm_files and scm_dirs must be absolute with symlinks resolved (realpath),
     with normalized case (normcase)
@@ -38,7 +42,7 @@ def scm_find_files(
             fn = os.path.join(realdirpath, os.path.normcase(n))
             return os.path.islink(fn) and fn not in scm_files
 
-        if realdirpath not in scm_dirs:
+        if not force_all_files and realdirpath not in scm_dirs:
             # directory not in scm, don't walk it's content
             dirnames[:] = []
             continue
@@ -54,13 +58,16 @@ def scm_find_files(
             # symlink loop protection
             dirnames[:] = []
             continue
-        dirnames[:] = [dn for dn in dirnames if not _link_not_in_scm(dn)]
+        dirnames[:] = [
+            dn for dn in dirnames if force_all_files or not _link_not_in_scm(dn)
+        ]
         for filename in filenames:
-            if _link_not_in_scm(filename):
+            if not force_all_files and _link_not_in_scm(filename):
                 continue
             # dirpath + filename with symlinks preserved
             fullfilename = os.path.join(dirpath, filename)
-            if os.path.normcase(os.path.realpath(fullfilename)) in scm_files:
+            is_tracked = os.path.normcase(os.path.realpath(fullfilename)) in scm_files
+            if force_all_files or is_tracked:
                 res.append(os.path.join(path, os.path.relpath(fullfilename, realpath)))
         seen.add(realdirpath)
     return res
